'use client';
import { useProfile } from '@/lib/hooks/useProfile';
import { AvatarUpload, ProfileForm } from '@/components/default/profile';
import {
  Card,
  CardContent,
  CardHeader,
  CardTitle,
  CardDescription,
  Separator,
} from '@/components/ui';
import { Loader2 } from 'lucide-react';

const ProfilePage = () => {
  const { profile, isLoading, updateProfile } = useProfile();

  const handleAvatarUploaded = async (path: string) => {
    await updateProfile({ avatar_url: path });
  };

  const handleProfileSubmit = async (values: { full_name: string; email: string }) => {
    await updateProfile({
      full_name: values.full_name,
      email: values.email,
    });
  };

  if (profile === undefined && !isLoading)
    return (
      <div className='flex p-5 items-center justify-center'>
        <h1>Unauthorized</h1>
      </div>
    );
    
  return (
    <div className="max-w-3xl mx-auto p-4">
      <Card className="mb-8">
        <CardHeader className="pb-2">
          <CardTitle className="text-2xl">Your Profile</CardTitle>
          <CardDescription>
            Manage your personal information and how it appears to others
          </CardDescription>
        </CardHeader>
        <CardContent>
          {isLoading && !profile ? (
            <div className="flex justify-center py-8">
              <Loader2 className="h-8 w-8 animate-spin text-gray-500" />
            </div>
          ) : (
            <div className="space-y-8">
              <AvatarUpload 
                profile={profile} 
                onAvatarUploaded={handleAvatarUploaded} 
              />

              <Separator />

              <ProfileForm 
                profile={profile} 
                isLoading={isLoading} 
                onSubmit={handleProfileSubmit} 
              />
            </div>
          )}
        </CardContent>
      </Card>
    </div>
  );
};

export default ProfilePage;
